@@ -1,5 +1,4 @@
-/*  commands/changepincommand.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2020 g10 Code GmbH
     SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
@@ -36,6 +35,7 @@ class ChangePinCommand::Private : public CardCommand::Private
     {
         return static_cast<ChangePinCommand *>(q);
     }
+
 public:
     explicit Private(ChangePinCommand *qq, const std::string &serialNumber, const std::string &appName, QWidget *p);
     ~Private() override;
@@ -102,7 +102,6 @@ void ChangePinCommand::setMode(ChangePinMode mode)
     d->mode = mode;
 }
 
-
 void ChangePinCommand::doStart()
 {
     qCDebug(KLEOPATRA_LOG) << "ChangePinCommand::doStart()";
@@ -138,7 +137,8 @@ void ChangePinCommand::Private::changePin()
     });
 }
 
-namespace {
+namespace
+{
 static QString errorMessage(const std::string &keyRef, ChangePinCommand::ChangePinMode mode, const QString &errorText)
 {
     // see cmd_passwd() in gpg-card.c
@@ -146,14 +146,15 @@ static QString errorMessage(const std::string &keyRef, ChangePinCommand::ChangeP
         return i18nc("@info", "Changing the PUK failed: %1", errorText);
     }
     if (keyRef == OpenPGPCard::resetCodeKeyRef()) {
-        return i18nc("@info", "Unblocking the PIN failed: %1", errorText);
+        if (mode == ChangePinCommand::ResetMode) {
+            return i18nc("@info", "Changing the PUK failed: %1", errorText);
+        } else {
+            return i18nc("@info", "Unblocking the PIN failed: %1", errorText);
+        }
     }
     if (keyRef == OpenPGPCard::adminPinKeyRef()) {
         return i18nc("@info", "Changing the Admin PIN failed: %1", errorText);
     }
-    if (keyRef == OpenPGPCard::resetCodeKeyRef() && mode == ChangePinCommand::ResetMode) {
-        return i18nc("@info", "Changing the Reset Code failed: %1", errorText);
-    }
     if (keyRef == NetKeyCard::nksPinKeyRef()) {
         if (mode == ChangePinCommand::NullPinMode) {
             return i18nc("@info", "Setting the NKS PIN failed: %1", errorText);
@@ -175,17 +176,18 @@ static QString successMessage(const std::string &keyRef, ChangePinCommand::Chang
 {
     // see cmd_passwd() in gpg-card.c
     if (keyRef == PIVCard::pukKeyRef()) {
-        return i18nc("@info", "PUK successfully changed.");
+        return i18nc("@info", "PUK changed successfully.");
     }
     if (keyRef == OpenPGPCard::resetCodeKeyRef()) {
-        return i18nc("@info", "Unblocked and set a new PIN successfully.");
+        if (mode == ChangePinCommand::ResetMode) {
+            return i18nc("@info", "PUK changed successfully.");
+        } else {
+            return i18nc("@info", "Unblocked and set a new PIN successfully.");
+        }
     }
     if (keyRef == OpenPGPCard::adminPinKeyRef()) {
         return i18nc("@info", "Admin PIN changed successfully.");
     }
-    if (keyRef == OpenPGPCard::resetCodeKeyRef() && mode == ChangePinCommand::ResetMode) {
-        return i18nc("@info", "Reset Code changed successfully.");
-    }
     if (keyRef == NetKeyCard::nksPinKeyRef()) {
         if (mode == ChangePinCommand::NullPinMode) {
             return i18nc("@info", "NKS PIN set successfully.");
@@ -204,16 +206,15 @@ static QString successMessage(const std::string &keyRef, ChangePinCommand::Chang
 }
 }
 
-void ChangePinCommand::Private::slotResult(const GpgME::Error& err)
+void ChangePinCommand::Private::slotResult(const GpgME::Error &err)
 {
-    qCDebug(KLEOPATRA_LOG) << "ChangePinCommand::slotResult():"
-                           << Formatting::errorAsString(err) << "(" << err.code() << ")";
+    qCDebug(KLEOPATRA_LOG) << "ChangePinCommand::slotResult():" << Formatting::errorAsString(err) << "(" << err.code() << ")";
     if (err) {
         error(errorMessage(keyRef, mode, Formatting::errorAsString(err)));
     } else if (!err.isCanceled()) {
         success(successMessage(keyRef, mode));
-        ReaderStatus::mutableInstance()->updateStatus();
     }
+    ReaderStatus::mutableInstance()->updateStatus();
     finished();
 }
 
