@@ -16,7 +16,6 @@
 #include <memory>
 #include <vector>
 
-class QModelIndex;
 template<typename T>
 class QList;
 class QAbstractItemView;
@@ -30,7 +29,6 @@ namespace Kleo
 {
 
 class KeyListController;
-class AbstractKeyListSortFilterProxyModel;
 
 class Command : public QObject, public ExecutionContext
 {
@@ -123,9 +121,6 @@ private:
 private:
     void applyWindowID(QWidget *wid) const override;
 
-protected:
-    void addTemporaryView(const QString &title, AbstractKeyListSortFilterProxyModel *proxy = nullptr, const QString &tabToolTip = QString());
-
 protected:
     class Private;
     const std::unique_ptr<Private> d;
