@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    commands/exportopenpgpcerttoprovidercommand.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2022 Felix Tiede
 
@@ -13,9 +11,9 @@
 #include "exportopenpgpcerttoprovidercommand.h"
 
 #ifdef MAILAKONADI_ENABLED
+#include <Akonadi/MessageQueueJob>
 #include <KIdentityManagementCore/Identity>
 #include <KIdentityManagementCore/IdentityManager>
-#include <Akonadi/MessageQueueJob>
 #include <MailTransport/TransportManager>
 #endif // MAILAKONADI_ENABLED
 
