@@ -31,6 +31,8 @@
 
 #include <QGpgME/KeyGenerationJob>
 #include <QGpgME/Protocol>
+#include <QGpgME/QuickJob>
+#include <qgpgme/qgpgme_version.h>
 
 #include <QProgressDialog>
 #include <QSettings>
@@ -38,6 +40,8 @@
 #include <gpgme++/context.h>
 #include <gpgme++/keygenerationresult.h>
 
+#include <gpgme.h>
+
 #include <kleopatra_debug.h>
 
 using namespace Kleo;
@@ -59,16 +63,18 @@ public:
 
     void getCertificateDetails();
     void createCertificate();
-    void showResult(const KeyGenerationResult &result);
+    void handleKeyGenerationResult(const KeyGenerationResult &result);
     void showErrorDialog(const KeyGenerationResult &result);
 
 private:
     KeyParameters keyParameters;
     bool protectKeyWithPassword = false;
+    bool teamKey = false;
     EmptyPassphraseProvider emptyPassphraseProvider;
     QPointer<OpenPGPCertificateCreationDialog> detailsDialog;
     QPointer<QGpgME::Job> job;
     QPointer<QProgressDialog> progressDialog;
+    std::shared_ptr<KeyCacheAutoRefreshSuspension> keyCacheAutoRefreshSuspension;
 };
 
 NewOpenPGPCertificateCommand::Private *NewOpenPGPCertificateCommand::d_func()
@@ -87,6 +93,7 @@ void NewOpenPGPCertificateCommand::Private::getCertificateDetails()
 {
     detailsDialog = new OpenPGPCertificateCreationDialog;
     detailsDialog->setAttribute(Qt::WA_DeleteOnClose);
+    detailsDialog->showTeamKeyOption(true);
     applyWindowID(detailsDialog);
 
     if (keyParameters.protocol() == KeyParameters::NoProtocol) {
@@ -109,6 +116,7 @@ void NewOpenPGPCertificateCommand::Private::getCertificateDetails()
     connect(detailsDialog, &QDialog::accepted, q, [this]() {
         keyParameters = detailsDialog->keyParameters();
         protectKeyWithPassword = detailsDialog->protectKeyWithPassword();
+        teamKey = detailsDialog->isTeamKey();
         QMetaObject::invokeMethod(
             q,
             [this] {
@@ -143,11 +151,13 @@ void NewOpenPGPCertificateCommand::Private::createCertificate()
         keyParameters.setComment(settings->value(QStringLiteral("uidcomment"), {}).toString());
     }
 
+    keyCacheAutoRefreshSuspension = KeyCache::mutableInstance()->suspendAutoRefresh();
+
     connect(keyGenJob, &QGpgME::KeyGenerationJob::result, q, [this](const KeyGenerationResult &result) {
         QMetaObject::invokeMethod(
             q,
             [this, result] {
-                showResult(result);
+                handleKeyGenerationResult(result);
             },
             Qt::QueuedConnection);
     });
@@ -174,7 +184,7 @@ void NewOpenPGPCertificateCommand::Private::createCertificate()
     progressDialog->show();
 }
 
-void NewOpenPGPCertificateCommand::Private::showResult(const KeyGenerationResult &result)
+void NewOpenPGPCertificateCommand::Private::handleKeyGenerationResult(const KeyGenerationResult &result)
 {
     if (result.error().isCanceled()) {
         finished();
@@ -187,7 +197,7 @@ void NewOpenPGPCertificateCommand::Private::showResult(const KeyGenerationResult
         std::unique_ptr<Context> ctx{Context::createForProtocol(OpenPGP)};
         if (ctx) {
             Error err;
-            ctx->addKeyListMode(GpgME::Validate);
+            ctx->addKeyListMode(KeyListMode::Validate | KeyListMode::Signatures | KeyListMode::SignatureNotations);
             key = ctx->key(result.fingerprint(), err, /*secret=*/true);
             if (!key.isNull()) {
                 KeyCache::mutableInstance()->insert(key);
@@ -195,14 +205,74 @@ void NewOpenPGPCertificateCommand::Private::showResult(const KeyGenerationResult
         }
     }
 
-    if (!key.isNull()) {
+    if (key.isNull()) {
+        showErrorDialog(result);
+        finished();
+        return;
+    }
+
+    if (teamKey) {
+        auto quickJob = std::unique_ptr<QGpgME::QuickJob>(QGpgME::openpgp()->quickJob());
+#if QGPGME_VERSION >= QT_VERSION_CHECK(2, 0, 0)
+        auto flags = GpgME::Context::CreationFlags::CreateSign;
+        if (!protectKeyWithPassword) {
+            flags |= GpgME::Context::CreationFlags::CreateNoPassword;
+        }
+#else
+        auto flags = GPGME_CREATE_SIGN;
+        if (!protectKeyWithPassword) {
+            flags |= GPGME_CREATE_NOPASSWD;
+        }
+#endif
+        connect(quickJob.get(), &QGpgME::QuickJob::result, q, [this, result](const auto &err) {
+            if (err) {
+                error(i18nc("@info", "Failed to create signing subkey: %1", Formatting::errorAsString(err)));
+                finished();
+                return;
+            }
+
+            if (err.isCanceled()) {
+                finished();
+                return;
+            }
+
+            // Ensure that we have the key in the cache
+            Key key;
+            if (!result.error().code() && result.fingerprint()) {
+                std::unique_ptr<Context> ctx{Context::createForProtocol(OpenPGP)};
+                if (ctx) {
+                    Error err;
+                    ctx->addKeyListMode(KeyListMode::Validate | KeyListMode::Signatures | KeyListMode::SignatureNotations);
+                    key = ctx->key(result.fingerprint(), err, /*secret=*/true);
+                    if (!key.isNull()) {
+                        KeyCache::mutableInstance()->insert(key);
+                    }
+                }
+            }
+
+            success(xi18nc("@info",
+                           "<para>A new OpenPGP certificate was created successfully.</para>"
+                           "<para>Fingerprint of the new certificate: %1</para>",
+                           Formatting::prettyID(key.primaryFingerprint())));
+            finished();
+        });
+#if QGPGME_VERSION >= QT_VERSION_CHECK(2, 0, 0)
+        auto err = quickJob->startAddSubkey(key, QByteArray::fromStdString(key.subkey(0).algoName()), {}, flags);
+        if (err) {
+            error(i18nc("@info", "Failed to create signing subkey: %1", Formatting::errorAsString(err)));
+            finished();
+            return;
+        }
+#else
+        quickJob->startAddSubkey(key, QByteArray::fromStdString(key.subkey(0).algoName()).data(), {}, flags);
+#endif
+        quickJob.release();
+    } else {
         success(xi18nc("@info",
                        "<para>A new OpenPGP certificate was created successfully.</para>"
                        "<para>Fingerprint of the new certificate: %1</para>",
                        Formatting::prettyID(key.primaryFingerprint())));
         finished();
-    } else {
-        showErrorDialog(result);
     }
 }
 
