@@ -37,9 +37,6 @@ public:
     void showCloseButton(bool show);
     void setShowButton(const QString &text, bool show);
 
-public Q_SLOTS:
-    void showAuditLog();
-
 Q_SIGNALS:
     void linkActivated(const QString &link);
     void closeButtonClicked();
