@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    crypto/signencryptfilescontroller.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -16,10 +14,10 @@
 
 #include "signencrypttask.h"
 
-#include "crypto/gui/signencryptfileswizard.h"
+#include "crypto/gui/signencryptfilesdialog.h"
 #include "crypto/taskcollection.h"
 
-#include "fileoperationspreferences.h"
+#include <settings.h>
 
 #include "utils/archivedefinition.h"
 #include "utils/input.h"
@@ -77,7 +75,7 @@ private:
 private:
     std::vector<std::shared_ptr<SignEncryptTask>> runnable, completed;
     std::shared_ptr<SignEncryptTask> cms, openpgp;
-    QPointer<SignEncryptFilesWizard> wizard;
+    QPointer<SignEncryptFilesDialog> wizard;
     QStringList files;
     unsigned int operation;
     Protocol protocol;
@@ -230,7 +228,7 @@ static QString extension(bool pgp, bool sign, bool encrypt, bool ascii, bool det
         cls |= detached ? Class::DetachedSignature : Class::OpaqueSignature;
     }
     cls |= ascii ? Class::Ascii : Class::Binary;
-    const bool usePGPFileExt = FileOperationsPreferences().usePGPFileExt();
+    const bool usePGPFileExt = Settings().usePGPFileExt();
     const auto ext = outputFileExtension(cls, usePGPFileExt);
     if (!ext.isEmpty()) {
         return ext;
@@ -244,8 +242,7 @@ static std::shared_ptr<ArchiveDefinition> getDefaultAd()
     const std::vector<std::shared_ptr<ArchiveDefinition>> ads = ArchiveDefinition::getArchiveDefinitions();
     Q_ASSERT(!ads.empty());
     std::shared_ptr<ArchiveDefinition> ad = ads.front();
-    const FileOperationsPreferences prefs;
-    const QString archiveCmd = prefs.archiveCommand();
+    const QString archiveCmd = Settings{}.archiveCommand();
     auto it = std::find_if(ads.cbegin(), ads.cend(), [&archiveCmd](const std::shared_ptr<ArchiveDefinition> &toCheck) {
         return toCheck->id() == archiveCmd;
     });
@@ -273,15 +270,14 @@ static QMap<int, QString> buildOutputNames(const QStringList &files, const bool
     } else {
         baseNameCms = baseNamePgp = files.first() + QLatin1Char('.');
     }
-    const FileOperationsPreferences prefs;
-    const bool ascii = prefs.addASCIIArmor();
+    const bool ascii = Settings{}.addASCIIArmor();
 
-    nameMap.insert(SignEncryptFilesWizard::SignatureCMS, baseNameCms + extension(false, true, false, ascii, true));
-    nameMap.insert(SignEncryptFilesWizard::EncryptedCMS, baseNameCms + extension(false, false, true, ascii, false));
-    nameMap.insert(SignEncryptFilesWizard::CombinedPGP, baseNamePgp + extension(true, true, true, ascii, false));
-    nameMap.insert(SignEncryptFilesWizard::EncryptedPGP, baseNamePgp + extension(true, false, true, ascii, false));
-    nameMap.insert(SignEncryptFilesWizard::SignaturePGP, baseNamePgp + extension(true, true, false, ascii, true));
-    nameMap.insert(SignEncryptFilesWizard::Directory, heuristicBaseDirectory(files));
+    nameMap.insert(SignEncryptFilesDialog::SignatureCMS, baseNameCms + extension(false, true, false, ascii, true));
+    nameMap.insert(SignEncryptFilesDialog::EncryptedCMS, baseNameCms + extension(false, false, true, ascii, false));
+    nameMap.insert(SignEncryptFilesDialog::CombinedPGP, baseNamePgp + extension(true, true, true, ascii, false));
+    nameMap.insert(SignEncryptFilesDialog::EncryptedPGP, baseNamePgp + extension(true, false, true, ascii, false));
+    nameMap.insert(SignEncryptFilesDialog::SignaturePGP, baseNamePgp + extension(true, true, false, ascii, true));
+    nameMap.insert(SignEncryptFilesDialog::Directory, heuristicBaseDirectory(files));
     return nameMap;
 }
 
@@ -289,7 +285,7 @@ static QMap<int, QString> buildOutputNamesForDir(const QString &file, const QMap
 {
     QMap<int, QString> ret;
 
-    const QString dir = orig.value(SignEncryptFilesWizard::Directory);
+    const QString dir = orig.value(SignEncryptFilesDialog::Directory);
     if (dir.isEmpty()) {
         return orig;
     }
@@ -298,14 +294,13 @@ static QMap<int, QString> buildOutputNamesForDir(const QString &file, const QMap
     const QFileInfo fi(file);
     const QString baseName = dir + QLatin1Char('/') + fi.fileName() + QLatin1Char('.');
 
-    const FileOperationsPreferences prefs;
-    const bool ascii = prefs.addASCIIArmor();
+    const bool ascii = Settings{}.addASCIIArmor();
 
-    ret.insert(SignEncryptFilesWizard::SignatureCMS, baseName + extension(false, true, false, ascii, true));
-    ret.insert(SignEncryptFilesWizard::EncryptedCMS, baseName + extension(false, false, true, ascii, false));
-    ret.insert(SignEncryptFilesWizard::CombinedPGP, baseName + extension(true, true, true, ascii, false));
-    ret.insert(SignEncryptFilesWizard::EncryptedPGP, baseName + extension(true, false, true, ascii, false));
-    ret.insert(SignEncryptFilesWizard::SignaturePGP, baseName + extension(true, true, false, ascii, true));
+    ret.insert(SignEncryptFilesDialog::SignatureCMS, baseName + extension(false, true, false, ascii, true));
+    ret.insert(SignEncryptFilesDialog::EncryptedCMS, baseName + extension(false, false, true, ascii, false));
+    ret.insert(SignEncryptFilesDialog::CombinedPGP, baseName + extension(true, true, true, ascii, false));
+    ret.insert(SignEncryptFilesDialog::EncryptedPGP, baseName + extension(true, false, true, ascii, false));
+    ret.insert(SignEncryptFilesDialog::SignaturePGP, baseName + extension(true, true, false, ascii, true));
     return ret;
 }
 
@@ -472,11 +467,11 @@ static std::vector<std::shared_ptr<SignEncryptTask>> createSignEncryptTasksForFi
         // Symmetric encryption is only supported for PGP
         int outKind = 0;
         if ((!pgpRecipients.empty() || symmetric) && !pgpSigners.empty()) {
-            outKind = SignEncryptFilesWizard::CombinedPGP;
+            outKind = SignEncryptFilesDialog::CombinedPGP;
         } else if (!pgpRecipients.empty() || symmetric) {
-            outKind = SignEncryptFilesWizard::EncryptedPGP;
+            outKind = SignEncryptFilesDialog::EncryptedPGP;
         } else {
-            outKind = SignEncryptFilesWizard::SignaturePGP;
+            outKind = SignEncryptFilesDialog::SignaturePGP;
         }
         result.push_back(createSignEncryptTaskForFileInfo(fi, ascii, pgpRecipients, pgpSigners, outputNames[outKind], symmetric));
     }
@@ -486,11 +481,11 @@ static std::vector<std::shared_ptr<SignEncryptTask>> createSignEncryptTasksForFi
         // then sign, or sign then encrypt. Ugly.
         if (!cmsSigners.empty()) {
             result.push_back(
-                createSignEncryptTaskForFileInfo(fi, ascii, std::vector<Key>(), cmsSigners, outputNames[SignEncryptFilesWizard::SignatureCMS], false));
+                createSignEncryptTaskForFileInfo(fi, ascii, std::vector<Key>(), cmsSigners, outputNames[SignEncryptFilesDialog::SignatureCMS], false));
         }
         if (!cmsRecipients.empty()) {
             result.push_back(
-                createSignEncryptTaskForFileInfo(fi, ascii, cmsRecipients, std::vector<Key>(), outputNames[SignEncryptFilesWizard::EncryptedCMS], false));
+                createSignEncryptTaskForFileInfo(fi, ascii, cmsRecipients, std::vector<Key>(), outputNames[SignEncryptFilesDialog::EncryptedCMS], false));
         }
     }
 
@@ -518,11 +513,11 @@ static std::vector<std::shared_ptr<SignEncryptTask>> createArchiveSignEncryptTas
     if (pgp || symmetric) {
         int outKind = 0;
         if ((!pgpRecipients.empty() || symmetric) && !pgpSigners.empty()) {
-            outKind = SignEncryptFilesWizard::CombinedPGP;
+            outKind = SignEncryptFilesDialog::CombinedPGP;
         } else if (!pgpRecipients.empty() || symmetric) {
-            outKind = SignEncryptFilesWizard::EncryptedPGP;
+            outKind = SignEncryptFilesDialog::EncryptedPGP;
         } else {
-            outKind = SignEncryptFilesWizard::SignaturePGP;
+            outKind = SignEncryptFilesDialog::SignaturePGP;
         }
         result.push_back(createArchiveSignEncryptTaskForFiles(files, ad, true, ascii, pgpRecipients, pgpSigners, outputNames[outKind], symmetric));
     }
@@ -534,7 +529,7 @@ static std::vector<std::shared_ptr<SignEncryptTask>> createArchiveSignEncryptTas
                                                                   ascii,
                                                                   std::vector<Key>(),
                                                                   cmsSigners,
-                                                                  outputNames[SignEncryptFilesWizard::SignatureCMS],
+                                                                  outputNames[SignEncryptFilesDialog::SignatureCMS],
                                                                   false));
         }
         if (!cmsRecipients.empty()) {
@@ -544,7 +539,7 @@ static std::vector<std::shared_ptr<SignEncryptTask>> createArchiveSignEncryptTas
                                                                   ascii,
                                                                   cmsRecipients,
                                                                   std::vector<Key>(),
-                                                                  outputNames[SignEncryptFilesWizard::EncryptedCMS],
+                                                                  outputNames[SignEncryptFilesDialog::EncryptedCMS],
                                                                   false));
         }
     }
@@ -616,14 +611,13 @@ void SignEncryptFilesController::Private::slotWizardOperationPrepared()
         kleo_assert(wizard);
         kleo_assert(!files.empty());
 
-        const bool archive = ((wizard->outputNames().value(SignEncryptFilesWizard::Directory).isNull() && files.size() > 1) //
+        const bool archive = ((wizard->outputNames().value(SignEncryptFilesDialog::Directory).isNull() && files.size() > 1) //
                               || ((operation & ArchiveMask) == ArchiveForced));
 
         const std::vector<Key> recipients = wizard->resolvedRecipients();
         const std::vector<Key> signers = wizard->resolvedSigners();
 
-        const FileOperationsPreferences prefs;
-        const bool ascii = prefs.addASCIIArmor();
+        const bool ascii = Settings{}.addASCIIArmor();
 
         std::vector<Key> pgpRecipients, cmsRecipients, pgpSigners, cmsSigners;
         for (const Key &k : recipients) {
@@ -795,7 +789,7 @@ void SignEncryptFilesController::Private::ensureWizardCreated()
         return;
     }
 
-    std::unique_ptr<SignEncryptFilesWizard> w(new SignEncryptFilesWizard);
+    std::unique_ptr<SignEncryptFilesDialog> w(new SignEncryptFilesDialog);
     w->setAttribute(Qt::WA_DeleteOnClose);
 
     connect(w.get(), SIGNAL(operationPrepared()), q, SLOT(slotWizardOperationPrepared()), Qt::QueuedConnection);
