@@ -81,7 +81,9 @@ void CertifyCertificateDialog::setCertificateToCertify(const Key &key, const std
     Q_ASSERT(std::ranges::all_of(uids, [key](const auto &uid) {
         return Kleo::userIDBelongsToKey(uid, key);
     }));
-    setWindowTitle(i18nc("@title:window arg is name, email of certificate holder", "Certify Certificate: %1", Formatting::prettyName(key)));
+    const QString name = Formatting::prettyName(key);
+    setWindowTitle(
+        i18nc("@title:window arg is name, email of certificate holder", "Certify Certificate: %1", !name.isEmpty() ? name : Formatting::prettyEMail(key)));
     mCertWidget->setCertificate(key, uids);
 }
 
