@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    dialogs/signcertificatedialog.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
 
@@ -15,8 +13,6 @@
 
 #include <gpgme++/key.h>
 
-#include <utils/pimpl_ptr.h>
-
 namespace Kleo
 {
 
