@@ -10,7 +10,6 @@
 
 #include "certifywidget.h"
 
-#include "dialogs/animatedexpander.h"
 #include "view/infofield.h"
 #include <utils/accessibility.h>
 #include <utils/gui-helper.h>
@@ -28,6 +27,7 @@
 #include <KSharedConfig>
 
 #include <Libkleo/Algorithm>
+#include <Libkleo/AnimatedExpander>
 #include <Libkleo/DefaultKeyFilter>
 #include <Libkleo/Expiration>
 #include <Libkleo/Formatting>
@@ -426,6 +426,7 @@ public:
         mMode = mode;
         switch (mMode) {
         case SingleCertification:
+            mFprField->valueLabel()->setFocus();
             break;
         case BulkCertification: {
             mInfoLabel->setText(i18nc("@info",
@@ -434,6 +435,7 @@ public:
                                       "<i>Note: Only the fingerprints clearly identify the certificate and its owner.</i>"));
             mFprField->setVisible(false);
             mTrustSignatureWidgets.setVisible(false);
+            mSecKeySelect->setFocus();
             break;
         }
         }
