@@ -1,6 +1,5 @@
 #pragma once
-/*  dialogs/certifywidget.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2019 g 10code GmbH
 
@@ -9,13 +8,13 @@
 
 #include <QWidget>
 
-#include <vector>
 #include <memory>
+#include <vector>
 
 namespace GpgME
 {
-    class Key;
-    class UserID;
+class Key;
+class UserID;
 } // namespace GpgME
 
 namespace Kleo
@@ -30,16 +29,20 @@ public:
     ~CertifyWidget() override;
 
     /* Set the key to certify */
-    void setTarget(const GpgME::Key &key);
+    void setCertificate(const GpgME::Key &key, const std::vector<GpgME::UserID> &uids);
 
     /* Get the key to certify */
-    GpgME::Key target() const;
+    GpgME::Key certificate() const;
 
-    /* Select specific user ids. Default: all */
+    /* Sets the certificates to certify. Use for bulk certification. */
+    void setCertificates(const std::vector<GpgME::Key> &keys);
+    std::vector<GpgME::Key> certificates() const;
+
+    /* Select specific user IDs. Default: all */
     void selectUserIDs(const std::vector<GpgME::UserID> &uids);
 
-    /* The user ids that should be signed */
-    std::vector<unsigned int> selectedUserIDs() const;
+    /* The user IDs that should be signed */
+    std::vector<GpgME::UserID> selectedUserIDs() const;
 
     /* The secret key selected */
     GpgME::Key secKey() const;
@@ -64,6 +67,8 @@ public:
 
     bool isValid() const;
 
+    void saveState() const;
+
 Q_SIGNALS:
     void changed() const;
 
@@ -73,4 +78,3 @@ private:
 };
 
 } // namespace Kleo
-
