@@ -66,9 +66,11 @@
 #include <QSize>
 
 #include <QAbstractItemView>
+#include <QActionGroup>
 #include <QCloseEvent>
 #include <QDesktopServices>
 #include <QDir>
+#include <QHeaderView>
 #include <QLabel>
 #include <QMenu>
 #include <QMimeData>
@@ -127,7 +129,7 @@ class CertificateView : public QWidget, public FocusFirstChild
 {
     Q_OBJECT
 public:
-    CertificateView(QWidget *parent = nullptr)
+    explicit CertificateView(QWidget *parent = nullptr)
         : QWidget{parent}
         , ui{this}
     {
@@ -357,10 +359,12 @@ private:
 
     void keyListingDone()
     {
-        if (KeyCache::instance()->keys().empty()) {
-            showView(ui.welcomeWidget);
-        } else {
-            showView(ui.searchTab);
+        if (KeyCache::instance()->initialized()) {
+            if (KeyCache::instance()->keys().empty()) {
+                showView(ui.welcomeWidget);
+            } else {
+                showView(ui.searchTab);
+            }
         }
     }
 
@@ -372,6 +376,13 @@ private:
         CertificateView *searchTab = nullptr;
         WelcomeWidget *welcomeWidget = nullptr;
         QStackedWidget *stackWidget = nullptr;
+        KActionMenu *columnsMenu = nullptr;
+        KActionMenu *columnsSortMenu = nullptr;
+        QList<QAction *> actions;
+        QActionGroup *sortColumnActions = nullptr;
+        QActionGroup *sortOrderActions = nullptr;
+
+        TreeView *previousTreeView = nullptr;
         explicit UI(MainWindow *q);
     } ui;
     QAction *focusToClickSearchAction = nullptr;
@@ -434,6 +445,9 @@ MainWindow::Private::Private(MainWindow *qq)
     connect(KeyCache::instance().get(), &KeyCache::keyListingDone, q, [this]() {
         keyListingDone();
     });
+    connect(KeyCache::instance().get(), &KeyCache::keysMayHaveChanged, q, [this]() {
+        keyListingDone();
+    });
 
     q->createGUI(QStringLiteral("kleopatra.rc"));
 
@@ -529,7 +543,7 @@ void MainWindow::Private::setupActions()
 #endif
         {
             "tools_debug_view",
-            i18n("Show GnuPG Configuration"),
+            i18n("GnuPG Command Line"),
             QString(),
             "",
             q,
@@ -602,7 +616,7 @@ void MainWindow::Private::setupActions()
         },
         {
             "configure_groups",
-            i18n("Configure Groups..."),
+            i18n("Manage Groups..."),
             QString(),
             "group",
             q,
@@ -655,6 +669,22 @@ void MainWindow::Private::setupActions()
     clipboadMenu->clipboardMenu()->setPopupMode(QToolButton::InstantPopup);
     coll->addAction(QStringLiteral("clipboard_menu"), clipboadMenu->clipboardMenu());
 
+    ui.columnsMenu = new KActionMenu(i18nc("@action:inmenu", "Configure visible columns"), q);
+    ui.columnsMenu->setPopupMode(QToolButton::InstantPopup);
+    ui.columnsMenu->setIcon(QIcon::fromTheme(u"show_table_column"_s));
+    coll->addAction(QStringLiteral("columns_menu"), ui.columnsMenu);
+    ui.sortColumnActions = new QActionGroup(q);
+    ui.sortOrderActions = new QActionGroup(q);
+
+    ui.columnsSortMenu = new KActionMenu(i18nc("@action:inmenu", "Configure table sort order"), q);
+    coll->addAction(QStringLiteral("columns_sort_menu"), ui.columnsSortMenu);
+
+    connect(ui.searchTab->tabWidget(),
+            &TabWidget::viewAdded,
+            q,
+            &MainWindow::setupColumnVisibility,
+            (Qt::ConnectionType)(Qt::SingleShotConnection | Qt::QueuedConnection));
+
     /* Add additional help actions for documentation */
     const auto compendium = new DocAction(QIcon{u":/gpg4win/gpg4win-compact"_s},
                                           i18n("Gpg4win Compendium"),
@@ -906,5 +936,95 @@ std::unique_ptr<DocAction> MainWindow::createSymmetricGuideAction(QObject *paren
         parent);
 }
 
+void MainWindow::setupColumnVisibility()
+{
+    const auto model = d->ui.searchTab->tabWidget()->currentView()->model();
+
+    for (auto i = 0; i < model->columnCount(); ++i) {
+        auto action = new QAction(this);
+        action->setText(model->headerData(i, Qt::Horizontal, Qt::DisplayRole).toString());
+        action->setCheckable(true);
+        d->ui.columnsMenu->addAction(action);
+        d->ui.actions += action;
+
+        auto sortOrderAction = new QAction(this);
+        sortOrderAction->setText(model->headerData(i, Qt::Horizontal, Qt::DisplayRole).toString());
+        sortOrderAction->setCheckable(true);
+        d->ui.columnsSortMenu->addAction(sortOrderAction);
+        d->ui.sortColumnActions->addAction(sortOrderAction);
+        connect(sortOrderAction, &QAction::triggered, this, [i, this](auto checked) {
+            if (checked) {
+                auto treeView = dynamic_cast<TreeView *>(d->ui.searchTab->tabWidget()->currentView());
+                treeView->header()->setSortIndicator(i, treeView->header()->sortIndicatorOrder());
+            }
+        });
+    }
+
+    d->ui.columnsSortMenu->addSeparator();
+    auto ascendingAction = new QAction(i18nc("@action:inmenu", "Ascending"));
+    ascendingAction->setCheckable(true);
+    d->ui.sortOrderActions->addAction(ascendingAction);
+    d->ui.columnsSortMenu->addAction(ascendingAction);
+    connect(ascendingAction, &QAction::triggered, this, [this](auto checked) {
+        if (checked) {
+            auto treeView = dynamic_cast<TreeView *>(d->ui.searchTab->tabWidget()->currentView());
+            treeView->header()->setSortIndicator(treeView->header()->sortIndicatorSection(), Qt::AscendingOrder);
+        }
+    });
+    auto descendingAction = new QAction(i18nc("@action:inmenu", "Descending"));
+    descendingAction->setCheckable(true);
+    d->ui.columnsSortMenu->addAction(descendingAction);
+    d->ui.sortOrderActions->addAction(descendingAction);
+    connect(descendingAction, &QAction::triggered, this, [this](auto checked) {
+        if (checked) {
+            auto treeView = dynamic_cast<TreeView *>(d->ui.searchTab->tabWidget()->currentView());
+            treeView->header()->setSortIndicator(treeView->header()->sortIndicatorSection(), Qt::DescendingOrder);
+        }
+    });
+
+    connect(d->ui.searchTab->tabWidget(), &TabWidget::currentViewChanged, this, &MainWindow::connectColumnVisibility);
+    connectColumnVisibility();
+}
+
+void MainWindow::connectColumnVisibility()
+{
+    if (d->ui.previousTreeView) {
+        disconnect(d->ui.previousTreeView, &TreeView::columnEnabled, this, nullptr);
+        disconnect(d->ui.previousTreeView, &TreeView::columnDisabled, this, nullptr);
+        disconnect(d->ui.previousTreeView->header(), &QHeaderView::sectionClicked, this, nullptr);
+    }
+
+    auto treeView = dynamic_cast<TreeView *>(d->ui.searchTab->tabWidget()->currentView());
+    const auto model = treeView->model();
+
+    for (auto i = 0; i < model->columnCount(); ++i) {
+        disconnect(d->ui.actions[i], &QAction::triggered, this, nullptr);
+        d->ui.actions[i]->setChecked(!treeView->isColumnHidden(i));
+        connect(d->ui.actions[i], &QAction::triggered, this, [this, i, treeView]() {
+            treeView->setColumnHidden(i, !d->ui.actions[i]->isChecked());
+            d->ui.sortColumnActions->actions()[i]->setVisible(d->ui.actions[i]->isChecked());
+        });
+        d->ui.sortColumnActions->actions()[i]->setVisible(!treeView->isColumnHidden(i));
+    }
+    connect(treeView, &TreeView::columnDisabled, this, [this](const auto index) {
+        d->ui.actions[index]->setChecked(false);
+        d->ui.sortColumnActions->actions()[index]->setVisible(false);
+    });
+    connect(treeView, &TreeView::columnEnabled, this, [this](const auto index) {
+        d->ui.actions[index]->setChecked(true);
+        d->ui.sortColumnActions->actions()[index]->setVisible(true);
+    });
+
+    connect(treeView->header(), &QHeaderView::sectionClicked, this, [this, treeView](auto index) {
+        d->ui.sortColumnActions->actions()[index]->setChecked(true);
+        d->ui.sortOrderActions->actions()[treeView->header()->sortIndicatorOrder()]->setChecked(true);
+    });
+
+    d->ui.sortColumnActions->actions()[treeView->header()->sortIndicatorSection()]->setChecked(true);
+    d->ui.sortOrderActions->actions()[treeView->header()->sortIndicatorOrder()]->setChecked(true);
+
+    d->ui.previousTreeView = treeView;
+}
+
 #include "mainwindow.moc"
 #include "moc_mainwindow.cpp"
