@@ -37,16 +37,7 @@ public:
     {
         m_skipped = true;
 
-        if (!hasFeature(AssuanEngineFeature, 0)) {
-            m_error = i18n("GpgME library too old");
-            m_explanation = i18nc("@info",
-                                  "Either the GpgME library itself is too old, "
-                                  "or the GpgME++ library was compiled against "
-                                  "an older GpgME that did not support connecting to gpg-agent.");
-            m_proposedFix = xi18nc("@info",
-                                   "Upgrade to <application>gpgme</application> 1.2.0 or higher, "
-                                   "and ensure that gpgme++ was compiled against it.");
-        } else if (ensureEngineVersion(GpgME::GpgConfEngine, 2, 1, 0)) {
+        if (ensureEngineVersion(GpgME::GpgConfEngine, 2, 1, 0)) {
             // 2.1 starts the agent on demand and requires it. So for 2.1.0 we can assume
             // autostart works and we don't need to care about the agent.
             m_skipped = false;
