@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    smartcard/readerstatus.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB
     SPDX-FileCopyrightText: 2020 g10 Code GmbH
@@ -22,12 +20,16 @@
 #include <Libkleo/GnuPG>
 #include <Libkleo/KeyCache>
 #include <Libkleo/Stl_Util>
+#include <Libkleo/StringUtils>
 
 #include <QGpgME/Debug>
+#include <QGpgME/ImportJob>
+#include <QGpgME/Protocol>
 
 #include <gpgme++/context.h>
 #include <gpgme++/defaultassuantransaction.h>
 #include <gpgme++/engineinfo.h>
+#include <gpgme++/importresult.h>
 
 #include <gpg-error.h>
 
@@ -47,6 +49,8 @@
 
 #include "kleopatra_debug.h"
 
+#include <set>
+
 using namespace Kleo;
 using namespace Kleo::SmartCard;
 using namespace GpgME;
@@ -78,6 +82,9 @@ static QDebug operator<<(QDebug s, const std::vector<std::pair<std::string, std:
 struct CardApp {
     std::string serialNumber;
     std::string appName;
+
+    // define default comparison for usage with std::set
+    auto operator<=>(const CardApp &) const = default;
 };
 
 static void
@@ -470,21 +477,26 @@ static void readKeyPairInfoFromPIVCard(const std::string &keyRef, PIVCard *pivCa
     pivCard->setCardInfo(keyPairInfoLines);
 }
 
-static void readCertificateFromPIVCard(const std::string &keyRef, PIVCard *pivCard, const std::shared_ptr<Context> &gpg_agent)
+static std::string readCertificateFromCard(const std::string &keyRef, const std::shared_ptr<Context> &gpg_agent)
 {
     Error err;
     const std::string command = std::string("SCD READCERT ") + keyRef;
     const std::string certificateData = Assuan::sendDataCommand(gpg_agent, command.c_str(), err);
     if (err && err.code() != GPG_ERR_NOT_FOUND) {
-        qCWarning(KLEOPATRA_LOG) << "Running" << command << "failed:" << err;
-        return;
+        qCWarning(KLEOPATRA_LOG) << __func__ << "Running" << command << "failed:" << err;
+        return {};
     }
-    if (certificateData.empty()) {
-        qCDebug(KLEOPATRA_LOG) << "readCertificateFromPIVCard(" << QString::fromStdString(keyRef) << "): No certificate stored on card";
-        return;
+    qCDebug(KLEOPATRA_LOG) << __func__ << "(" << QString::fromStdString(keyRef) << "):" //
+                           << (certificateData.empty() ? "No certificate stored on card" : "Found certificate stored on card");
+    return certificateData;
+}
+
+static void readCertificateFromPIVCard(const std::string &keyRef, PIVCard *pivCard, const std::shared_ptr<Context> &gpg_agent)
+{
+    const std::string certificateData = readCertificateFromCard(keyRef, gpg_agent);
+    if (!certificateData.empty()) {
+        pivCard->setCertificateData(keyRef, certificateData);
     }
-    qCDebug(KLEOPATRA_LOG) << "readCertificateFromPIVCard(" << QString::fromStdString(keyRef) << "): Found certificate stored on card";
-    pivCard->setCertificateData(keyRef, certificateData);
 }
 
 static void handle_piv_card(std::shared_ptr<Card> &ci, std::shared_ptr<Context> &gpg_agent)
@@ -716,6 +728,119 @@ static std::vector<std::shared_ptr<Card>> update_cardinfo(std::shared_ptr<Contex
     }
     return cards;
 }
+
+namespace
+{
+struct CertInfo {
+    int certType = -1;
+    std::string keyref;
+};
+
+static QDebug operator<<(QDebug s, const CertInfo &certInfo)
+{
+    return s << "CertInfo(" << certInfo.certType << ',' << certInfo.keyref << ')';
+}
+}
+
+static CertInfo parseCertInfoLine(std::string_view line)
+{
+    CertInfo result;
+    const std::vector<std::string_view> parts = Kleo::split(line, ' ', 3);
+    if (parts.size() < 2) {
+        qCWarning(KLEOPATRA_LOG) << "Invalid CERTINFO status line (too few values)" << line;
+        return result;
+    }
+    const auto certType = Kleo::svToInt(parts.front());
+    if (!certType) {
+        qCWarning(KLEOPATRA_LOG) << "Invalid CERTINFO status line (invalid CERTTYPE)" << line;
+        return result;
+    }
+    return {certType.value(), std::string{parts[1]}};
+}
+
+static std::vector<CertInfo> parseCertInfoLines(const std::vector<std::pair<std::string, std::string>> &statusLines)
+{
+    std::vector<CertInfo> certInfos;
+    Kleo::transform_if(
+        statusLines,
+        std::back_inserter(certInfos),
+        [](const auto &statusLine) {
+            return parseCertInfoLine(statusLine.second);
+        },
+        [](const auto &statusLine) {
+            return statusLine.first == "CERTINFO";
+        });
+    // remove invalid and unknown values
+    Kleo::erase_if(certInfos, [](const auto &certInfo) {
+        return certInfo.certType <= 0;
+    });
+    return certInfos;
+}
+
+static void importCardCertificates(std::shared_ptr<Context> &gpgAgent)
+{
+    Error err;
+
+    // retrieve information about the certificates stored on the card
+    const auto statusLines = Assuan::sendStatusLinesCommand(gpgAgent, "SCD LEARN --force", err);
+    if (err) {
+        return;
+    }
+    auto certInfos = parseCertInfoLines(statusLines);
+    // remove certificate information for unsupported certificate types (see gpg-agent's agent_handle_learn)
+    Kleo::erase_if(certInfos, [](const CertInfo &certInfo) {
+        return (certInfo.certType != 100) && (certInfo.certType != 101) && (certInfo.certType != 102) && (certInfo.certType != 111);
+    });
+    // sort the certificate information by certificate types in the same order as gpg-agent's agent_handle_learn, i.e.
+    //   111, /* Root CA */
+    //   101, /* trusted */
+    //   102, /* useful */
+    //   100, /* regular */
+    const auto certInfoIsLessThan = [](const CertInfo &lhs, const CertInfo &rhs) {
+        // first condition puts 111 and 101 before 102 and 100 and second condition puts the certs in the two groups in the right order
+        return ((lhs.certType & 0x01) > (rhs.certType & 0x01)) || (lhs.certType > rhs.certType);
+    };
+    std::sort(certInfos.begin(), certInfos.end(), certInfoIsLessThan);
+
+    for (const CertInfo &certInfo : certInfos) {
+        const std::string certificateData = readCertificateFromCard(certInfo.keyref, gpgAgent);
+        if (certificateData.empty()) {
+            qCDebug(KLEOPATRA_LOG) << __func__ << "No certificate data retrieved from the card for slot" << certInfo.keyref;
+            continue;
+        }
+        qCDebug(KLEOPATRA_LOG) << __func__ << "Retrieved certificate data from the card for slot" << certInfo.keyref;
+
+        const auto job = std::unique_ptr<QGpgME::ImportJob>(QGpgME::smime()->importJob());
+        const ImportResult result = job->exec(QByteArray::fromStdString(certificateData));
+        if (result.error()) {
+            qCDebug(KLEOPATRA_LOG) << __func__ << "Import of certificate data failed:" << result.error();
+        } else {
+            qCDebug(KLEOPATRA_LOG) << __func__ << "Imported certificate data: considered:" << result.numConsidered() << "imported:" << result.numImported();
+        }
+    }
+}
+
+static void learnCard(const std::string &serialNumber, const std::string &appName, std::shared_ptr<Context> &gpgAgent)
+{
+    Error err;
+    if (gpgHasMultiCardMultiAppSupport()) {
+        switchCard(gpgAgent, serialNumber, err);
+        if (!err) {
+            switchApp(gpgAgent, serialNumber, appName, err);
+        }
+        if (err) {
+            return;
+        }
+    }
+
+    importCardCertificates(gpgAgent);
+
+    if (gpgHasMultiCardMultiAppSupport() && appName != OpenPGPCard::AppName) {
+        // switch the card app back to OpenPGP; errors are ignored
+        GpgME::Error dummy;
+        switchCardBackToOpenPGPApp(gpgAgent, serialNumber, dummy);
+    }
+}
 } // namespace
 
 struct Transaction {
@@ -726,22 +851,12 @@ struct Transaction {
     AssuanTransaction *assuanTransaction;
 };
 
-static const Transaction learnCMSTransaction = {{"__all__", "__cms__"}, "__learn__", nullptr, nullptr, nullptr};
+static const QByteArray learnCardTransactionCommand = "__learn__";
 static const Transaction updateTransaction = {{"__all__", "__all__"}, "__update__", nullptr, nullptr, nullptr};
 static const Transaction quitTransaction = {{"__all__", "__all__"}, "__quit__", nullptr, nullptr, nullptr};
 
 namespace
 {
-static void logProcessOutput(const char *prefix, const char *label, const QByteArray &output)
-{
-    if (output.isEmpty()) {
-        return;
-    }
-    for (const auto &line : output.split('\n')) {
-        qCDebug(KLEOPATRA_LOG) << prefix << label << line;
-    }
-}
-
 class ReaderStatusThread : public QThread
 {
     Q_OBJECT
@@ -785,8 +900,8 @@ Q_SIGNALS:
     void updateCardStarted(const std::string &serialNumber, const std::string &appName);
     void updateFinished();
     void oneTransactionFinished(const GpgME::Error &err);
-    void startingLearnCards(GpgME::Protocol protocol);
-    void cardsLearned(GpgME::Protocol protocol);
+    void startingLearnCard(const std::string &serialNumber, const std::string &appName);
+    void cardLearned(const std::string &serialNumber, const std::string &appName);
 
 public Q_SLOTS:
     void deviceStatusChanged(const QByteArray &details)
@@ -801,12 +916,6 @@ public Q_SLOTS:
         addTransaction(updateTransaction);
     }
 
-    void learnCardsCMS()
-    {
-        qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread[GUI]::learnCardsCMS()";
-        addTransaction(learnCMSTransaction);
-    }
-
     void stop()
     {
         const QMutexLocker locker(&m_mutex);
@@ -832,37 +941,6 @@ private Q_SLOTS:
     }
 
 private:
-    void learnCMSCards()
-    {
-        QProcess process;
-        connect(&process, &QProcess::readyReadStandardOutput, &process, [&process]() {
-            logProcessOutput("learnCMSCards", "stdout:", process.readAllStandardOutput());
-        });
-        connect(&process, &QProcess::readyReadStandardError, &process, [&process]() {
-            logProcessOutput("learnCMSCards", "stderr:", process.readAllStandardError());
-        });
-
-        process.start(gpgSmPath(), {QStringLiteral("--learn-card"), QStringLiteral("-v")});
-        qCDebug(KLEOPATRA_LOG) << __func__ << "Running" << process.program() << process.arguments().join(QLatin1Char{' '});
-        if (!process.waitForStarted()) {
-            qCDebug(KLEOPATRA_LOG) << __func__ << "Starting" << process.program() << "failed";
-            return;
-        }
-        // ensure that gpgsm doesn't wait for input
-        process.closeWriteChannel();
-
-        const bool success = process.waitForFinished(60000); // 60 seconds should be more than enough
-
-        logProcessOutput(__func__, "stdout:", process.readAllStandardOutput());
-        logProcessOutput(__func__, "stderr:", process.readAllStandardError());
-        if (success) {
-            qCDebug(KLEOPATRA_LOG) << __func__ << "Running" << process.program() << process.arguments().join(QLatin1Char{' '}) << "succeeded";
-        } else {
-            qCDebug(KLEOPATRA_LOG) << __func__ << "Running" << process.program() << process.arguments().join(QLatin1Char{' '})
-                                   << "failed; error:" << process.error() << ", exit code:" << process.exitCode();
-        }
-    }
-
     void run() override
     {
         while (true) {
@@ -941,10 +1019,8 @@ private:
                             qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread: Card" << serialNumber << "with app" << appName << "was added";
                             Q_EMIT cardAdded(serialNumber, appName);
                         } else {
-                            if (*newCard != **matchingOldCard) {
-                                qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread: Card" << serialNumber << "with app" << appName << "changed";
-                                Q_EMIT cardChanged(serialNumber, appName);
-                            }
+                            qCDebug(KLEOPATRA_LOG) << "ReaderStatusThread: Card" << serialNumber << "with app" << appName << "changed";
+                            Q_EMIT cardChanged(serialNumber, appName);
                             oldCards.erase(matchingOldCard);
                         }
                         if (newCard->hasNKSNullPin() && firstCardWithNullPin.empty()) {
@@ -998,10 +1074,10 @@ private:
                 }
 
                 Q_EMIT updateFinished();
-            } else if (nullSlot && command == learnCMSTransaction.command) {
-                Q_EMIT startingLearnCards(GpgME::CMS);
-                learnCMSCards();
-                Q_EMIT cardsLearned(GpgME::CMS);
+            } else if (nullSlot && command == learnCardTransactionCommand) {
+                Q_EMIT startingLearnCard(cardApp.serialNumber, cardApp.appName);
+                learnCard(cardApp.serialNumber, cardApp.appName, gpgAgent);
+                Q_EMIT cardLearned(cardApp.serialNumber, cardApp.appName);
             } else {
                 GpgME::Error err;
                 if (gpgHasMultiCardMultiAppSupport()) {
@@ -1060,8 +1136,8 @@ public:
         connect(this, &::ReaderStatusThread::updateCardStarted, q, &ReaderStatus::onUpdateCardStarted);
         connect(this, &::ReaderStatusThread::updateFinished, q, &ReaderStatus::onUpdateFinished);
         connect(this, &::ReaderStatusThread::firstCardWithNullPinChanged, q, &ReaderStatus::firstCardWithNullPinChanged);
-        connect(this, &::ReaderStatusThread::startingLearnCards, q, &ReaderStatus::onStartingLearnCards);
-        connect(this, &::ReaderStatusThread::cardsLearned, q, &ReaderStatus::onCardsLearned);
+        connect(this, &::ReaderStatusThread::startingLearnCard, q, &ReaderStatus::onStartingLearnCard);
+        connect(this, &::ReaderStatusThread::cardLearned, q, &ReaderStatus::onCardLearned);
 
         if (DeviceInfoWatcher::isSupported()) {
             qCDebug(KLEOPATRA_LOG) << "ReaderStatus::Private: Using new DeviceInfoWatcher";
@@ -1100,7 +1176,7 @@ private:
     DeviceInfoWatcher devInfoWatcher;
     std::shared_ptr<KeyCacheAutoRefreshSuspension> keyCacheAutoRefreshSuspension;
     Action currentAction = NoAction;
-    bool learnCMSTransactionScheduled = false;
+    std::set<CardApp> learnCardTransactionScheduled;
 };
 
 ReaderStatus::ReaderStatus(QObject *parent)
@@ -1192,14 +1268,14 @@ void ReaderStatus::updateCard(const std::string &serialNumber, const std::string
     d->addTransaction(t);
 }
 
-void ReaderStatus::learnCards(GpgME::Protocol protocol)
+void ReaderStatus::learnCard(const std::string &serialNumber, const std::string &appName)
 {
-    qCDebug(KLEOPATRA_LOG) << __func__ << "- procotol:" << Formatting::displayName(protocol);
-    if (protocol == GpgME::CMS && !d->learnCMSTransactionScheduled) {
-        d->learnCMSTransactionScheduled = true;
-        d->learnCardsCMS();
-    } else {
-        qCDebug(KLEOPATRA_LOG) << __func__ << "unsupported protocol";
+    qCDebug(KLEOPATRA_LOG) << __func__ << "- card app:" << appName << serialNumber;
+    if (!d->learnCardTransactionScheduled.contains({serialNumber, appName})) {
+        d->learnCardTransactionScheduled.insert({serialNumber, appName});
+        const CardApp cardApp = {serialNumber, appName};
+        const Transaction t = {cardApp, learnCardTransactionCommand, nullptr, nullptr, nullptr};
+        d->addTransaction(t);
     }
 }
 
@@ -1304,24 +1380,24 @@ void ReaderStatus::onUpdateFinished()
     Q_EMIT updateFinished();
 }
 
-void ReaderStatus::onStartingLearnCards(GpgME::Protocol protocol)
+void ReaderStatus::onStartingLearnCard(const std::string &serialNumber, const std::string &appName)
 {
     qCDebug(KLEOPATRA_LOG) << __func__;
     setCurrentAction(LearnCards);
     // suspend automatic refreshes of the key cache while smart card keys are learned
     d->keyCacheAutoRefreshSuspension = KeyCache::mutableInstance()->suspendAutoRefresh();
-    Q_EMIT startingLearnCards(protocol);
+    Q_EMIT startingLearnCard(serialNumber, appName);
 }
 
-void ReaderStatus::onCardsLearned(GpgME::Protocol protocol)
+void ReaderStatus::onCardLearned(const std::string &serialNumber, const std::string &appName)
 {
     qCDebug(KLEOPATRA_LOG) << __func__;
     setCurrentAction(NoAction);
-    Q_EMIT cardsLearned(protocol);
-    d->learnCMSTransactionScheduled = false;
+    Q_EMIT cardLearned(serialNumber, appName);
+    d->learnCardTransactionScheduled.erase({serialNumber, appName});
     d->keyCacheAutoRefreshSuspension.reset();
     // force a reload of the key cache to ensure that all learned certificates are loaded
-    KeyCache::mutableInstance()->reload(protocol, KeyCache::ForceReload);
+    KeyCache::mutableInstance()->reload(Protocol::CMS, KeyCache::ForceReload);
 }
 
 std::shared_ptr<Card> ReaderStatus::getCardWithKeyRef(const std::string &serialNumber, const std::string &keyRef) const
