@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    utils/dragqueen.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -10,9 +8,9 @@
 #pragma once
 
 #include <QLabel>
-#include <QPointer>
-#include <QPoint>
 #include <QMimeData>
+#include <QPoint>
+#include <QPointer>
 
 namespace Kleo
 {
@@ -43,5 +41,3 @@ private:
 };
 
 }
-
-
