@@ -1,8 +1,6 @@
 /*
-    view/htmllabel.h
-
     This file is part of Kleopatra, the KDE keymanager
-    SPDX-FileCopyrightText: 2021 g10 Code GmbH
+    SPDX-FileCopyrightText: 2021, 2022 g10 Code GmbH
     SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
 
     SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +8,8 @@
 
 #pragma once
 
+#include <interfaces/anchorprovider.h>
+
 #include <QLabel>
 
 #include <memory>
@@ -17,7 +17,7 @@
 namespace Kleo
 {
 
-class HtmlLabel : public QLabel
+class HtmlLabel : public QLabel, public AnchorProvider
 {
     Q_OBJECT
 public:
@@ -29,6 +29,13 @@ public:
 
     void setLinkColor(const QColor &color);
 
+    // AnchorProvider
+    int numberOfAnchors() const override;
+    QString anchorText(int index) const override;
+    QString anchorHref(int index) const override;
+    void activateAnchor(int index) override;
+    int selectedAnchor() const override;
+
 protected:
     bool focusNextPrevChild(bool next) override;
 
