@@ -46,8 +46,6 @@
 #include "commands/newcertificatesigningrequestcommand.h"
 #include "commands/newopenpgpcertificatecommand.h"
 #include "commands/refreshcertificatescommand.h"
-#include "commands/refreshopenpgpcertscommand.h"
-#include "commands/refreshx509certscommand.h"
 #include "commands/reloadkeyscommand.h"
 #include "commands/revokecertificationcommand.h"
 #include "commands/revokekeycommand.h"
@@ -126,7 +124,6 @@ public:
         std::erase(views, o);
         std::erase(commands, o);
     }
-    void slotDoubleClicked(const QModelIndex &idx);
     void slotActivated(const QModelIndex &idx);
     void slotSelectionChanged(const QItemSelection &old, const QItemSelection &new_);
     void slotContextMenu(const QPoint &pos);
@@ -449,29 +446,6 @@ void KeyListController::createActions(KActionCollection *coll)
             nullptr,
             QString(),
         },
-        // View menu
-        {
-            "view_redisplay",
-            i18n("Redisplay"),
-            QString(),
-            "view-refresh",
-            nullptr,
-            nullptr,
-            QStringLiteral("F5"),
-        },
-        {
-            "view_stop_operations",
-            i18n("Stop Operation"),
-            QString(),
-            "process-stop",
-            this,
-            [this](bool) {
-                cancelCommands();
-            },
-            QStringLiteral("Escape"),
-            RegularQAction,
-            Disabled,
-        },
         {
             "view_certificate_details",
             i18n("Details"),
@@ -581,15 +555,15 @@ void KeyListController::createActions(KActionCollection *coll)
             nullptr,
             QString(),
         },
-        // Tools menu
+        // View menu
         {
-            "tools_refresh_openpgp_certificates",
-            i18n("Refresh OpenPGP Certificates"),
+            "reload_certificate_list",
+            i18n("Redisplay"),
             QString(),
             "view-refresh",
             nullptr,
             nullptr,
-            QString(),
+            QStringLiteral("F5"),
         },
         // Context Menu
         {
@@ -661,16 +635,6 @@ void KeyListController::createActions(KActionCollection *coll)
             nullptr,
             QString(),
         },
-        // Tools menu
-        {
-            "tools_refresh_x509_certificates",
-            i18n("Refresh S/MIME Certificates"),
-            QString(),
-            "view-refresh",
-            nullptr,
-            nullptr,
-            QString(),
-        },
         {
             "crl_clear_crl_cache",
             i18n("Clear CRL Cache"),
@@ -744,7 +708,7 @@ void KeyListController::createActions(KActionCollection *coll)
     registerActionForCommand<ChecksumCreateFilesCommand>(coll->action(QStringLiteral("file_checksum_create_files")));
     registerActionForCommand<ChecksumVerifyFilesCommand>(coll->action(QStringLiteral("file_checksum_verify_files")));
 
-    registerActionForCommand<ReloadKeysCommand>(coll->action(QStringLiteral("view_redisplay")));
+    registerActionForCommand<ReloadKeysCommand>(coll->action(QStringLiteral("reload_certificate_list")));
     // coll->action( "view_stop_operations" ) <-- already dealt with in make_actions_from_data()
     registerActionForCommand<DetailsCommand>(coll->action(QStringLiteral("view_certificate_details")));
 
@@ -776,9 +740,6 @@ void KeyListController::createActions(KActionCollection *coll)
     registerActionForCommand<RefreshCertificatesCommand>(coll->action(QStringLiteral("certificates_refresh")));
     //---
     registerActionForCommand<DumpCertificateCommand>(coll->action(QStringLiteral("certificates_dump_certificate")));
-
-    registerActionForCommand<RefreshX509CertsCommand>(coll->action(QStringLiteral("tools_refresh_x509_certificates")));
-    registerActionForCommand<RefreshOpenPGPCertsCommand>(coll->action(QStringLiteral("tools_refresh_openpgp_certificates")));
     //---
     registerActionForCommand<ImportCrlCommand>(coll->action(QStringLiteral("crl_import_crl")));
     //---
@@ -843,9 +804,6 @@ void KeyListController::Private::connectView(QAbstractItemView *view)
     connect(view, &QObject::destroyed, q, [this](QObject *obj) {
         slotDestroyed(obj);
     });
-    connect(view, &QAbstractItemView::doubleClicked, q, [this](const QModelIndex &index) {
-        slotDoubleClicked(index);
-    });
     connect(view, &QAbstractItemView::activated, q, [this](const QModelIndex &index) {
         slotActivated(index);
     });
@@ -875,7 +833,7 @@ void KeyListController::Private::connectCommand(Command *cmd)
     connect(cmd, &Command::progress, q, &KeyListController::progress);
 }
 
-void KeyListController::Private::slotDoubleClicked(const QModelIndex &idx)
+void KeyListController::Private::slotActivated(const QModelIndex &idx)
 {
     QAbstractItemView *const view = qobject_cast<QAbstractItemView *>(q->sender());
     if (!view || !ranges::binary_search(views, view)) {
@@ -889,15 +847,6 @@ void KeyListController::Private::slotDoubleClicked(const QModelIndex &idx)
     }
 }
 
-void KeyListController::Private::slotActivated(const QModelIndex &idx)
-{
-    Q_UNUSED(idx)
-    QAbstractItemView *const view = qobject_cast<QAbstractItemView *>(q->sender());
-    if (!view || !ranges::binary_search(views, view)) {
-        return;
-    }
-}
-
 void KeyListController::Private::slotSelectionChanged(const QItemSelection &old, const QItemSelection &new_)
 {
     Q_UNUSED(old)
