@@ -25,7 +25,6 @@ namespace Kleo
 {
 
 class AbstractKeyListModel;
-class AbstractKeyListSortFilterProxyModel;
 class KeyFilter;
 class KeyListModelInterface;
 class SearchBar;
@@ -50,8 +49,6 @@ public:
 
     QAbstractItemView *addView(const QString &title = QString(), const QString &keyFilterID = QString(), const QString &searchString = QString());
     QAbstractItemView *addView(const KConfigGroup &group, Options options);
-    QAbstractItemView *
-    addTemporaryView(const QString &title = QString(), AbstractKeyListSortFilterProxyModel *proxy = nullptr, const QString &tabToolTip = QString());
 
     void loadViews(const KSharedConfig::Ptr &config, const QString &configKeys, Options options = ShowKeys);
     void saveViews();
